require("obsidian").setup {
  -- Set workspace setting
  workspaces = {
    {
      name = "personal",
      path = "~/Documents/t0xa_vault",
    }
  },
  -- Disable conceal level to supress varning log message
  ui = {
    enable = false
  },
  -- Set notes subdir to store new notes
  notes_subdir = "Unsorted",
  new_notes_location = "notes_subdir",
  -- Set template params
  templates = {
    folder = "Templates",
    date_format = "%Y-%m-%d",
    time_format = "%H:%M",
    substitutions = {
      yesterday = function()
        return os.date("%Y-%m-%d", os.time() - 86400)
      end
    }
  },
  -- Set behaviour of following links
  follow_url_func = function(url)
    -- vim.fn.jobstart({ "open", url }) -- Mac OS
    vim.fn.jobstart({ "xdg-open", url }) -- linux
    -- vim.cmd(':silent exec "!start ' .. url .. '"') -- Windows
    -- vim.ui.open(url) -- need Neovim 0.10.0+
  end,
  -- Set behaviour for opening images
  follow_img_func = function(img)
    -- vim.fn.jobstart { "qlmanage", "-p", img }  -- Mac OS quick look preview
    vim.fn.jobstart({ "xdg-open", url }) -- linux
    -- vim.cmd(':silent exec "!start ' .. url .. '"') -- Windows
  end,
  -- Set sorting for creation date
  sort_by = "created",
  -- Set attachements new folder
  attachments = {
    img_folder = "Media"
  },
  -- Disable auto formatter for files
  disable_frontmatter = true,
}


-- Obsidian-related keybinds
vim.keymap.set("n", "<leader>oit", "<cmd>ObsidianTemplate<CR>",
  { silent = true, noremap = true, desc = "Obsidian: insert template" })
vim.keymap.set("n", "<leader>oo", "<cmd>ObsidianQuickSwitch<CR>",
  { silent = true, noremap = true, desc = "Obsidian: open file" })
vim.keymap.set("n", "<leader>opi", "<cmd>ObsidianPasteImg<CR>",
  { silent = true, noremap = true, desc = "Obsidian: paste image" })
vim.keymap.set("n", "<leader>or", "<cmd>ObsidianRename<CR>",
  { silent = true, noremap = true, desc = "Obsidian: rename file" })
vim.keymap.set("n", "<leader>ol", "<cmd>ObsidianToggleCheckbox<CR>",
  { silent = true, noremap = true, desc = "Obsidian: toggle checkbox" })
vim.keymap.set("n", "<leader>on", "<cmd>ObsidianNew<CR>", { silent = true, noremap = true, desc = "Obsidian: new file" })
vim.keymap.set("n", "<leader>otoc", "<cmd>ObsidianTOC<CR>",
  { silent = true, noremap = true, desc = "Obsidian: open TOC" })
vim.keymap.set("n", "<leader>ofl", "<cmd>ObsidianFollowLink<CR>",
  { silent = true, noremap = true, desc = "Obsidian: follow link" })
vim.keymap.set("n", "<leader>otl", "<cmd>ObsidianTags<CR>",
  { silent = true, noremap = true, desc = "Obsidian: Get tags list" })
vim.keymap.set("n", "<leader>osb", "<cmd>ObsidianBacklinks<CR>",
  { silent = true, noremap = true, desc = "Obsidian: Show Backlinks" })
vim.keymap.set("n", "<leader>osl", "<cmd>ObsidianLinks<CR>",
  { silent = true, noremap = true, desc = "Obsidian: Show Links" })
